@@ -1,13 +1,9 @@
 #' @export
-store_new.keras <- function(format, file = NULL, resources = NULL) {
-  keras_new(file, resources)
+store_class_format.keras <- function(format) {
+  store_class_format_keras
 }
 
-keras_new <- function(file = NULL, resources = NULL) {
-  force(file)
-  force(resources)
-  enclass(environment(), c("tar_keras", "tar_nonexportable", "tar_store"))
-}
+store_class_format_keras <- c("tar_keras", "tar_nonexportable", "tar_store")
 
 #' @export
 store_assert_format_setting.keras <- function(format) {
