@@ -1,6 +1,6 @@
 meta_init <- function(path_store = path_store_default()) {
   database <- database_meta(path_store = path_store)
-  depends <- memory_init()
+  depends <- lookup_new()
   meta_new(
     database = database,
     depends = depends,
@@ -21,6 +21,7 @@ meta_class <- R6::R6Class(
     database = NULL,
     depends = NULL,
     store = NULL,
+    repository_cas_lookup_table = NULL,
     initialize = function(
       database = NULL,
       depends = NULL,
@@ -31,7 +32,7 @@ meta_class <- R6::R6Class(
       self$store <- store
     },
     get_depend = function(name) {
-      memory_get_object(self$depends, name)
+      lookup_get(.subset2(self, "depends"), name)
     },
     get_record = function(name) {
       record_from_row(
@@ -89,7 +90,7 @@ meta_class <- R6::R6Class(
       hash_object(string)
     },
     produce_depend = function(target, pipeline) {
-      self$hash_deps(target$command$deps, pipeline)
+      self$hash_deps(.subset2(target, "deps"), pipeline)
     },
     handle_error = function(record) {
       if (!self$exists_record(record$name)) {
@@ -117,6 +118,37 @@ meta_class <- R6::R6Class(
       data <- self$data_imports(envir, pipeline)
       self$database$set_data(data)
     },
+    preprocess = function(write = FALSE) {
+      data <- self$database$read_condensed_data()
+      self$update_repository_cas_lookup_table(data)
+      self$database$preprocess(data = data, write = write)
+      tar_runtime$meta <- self
+    },
+    ensure_preprocessed = function(write = FALSE) {
+      if (lookup_count(self$database$lookup) < 1L) {
+        self$preprocess(write = write)
+      }
+    },
+    update_repository_cas_lookup_table = function(data) {
+      data <- data[!is.na(data$repository), c("data", "repository")]
+      hashes <- split(x = data$data, f = data$repository)
+      lookup_table <- lookup_new()
+      for (name in names(hashes)) {
+        lookup_set(
+          lookup = lookup_table,
+          names = name,
+          object = .subset2(hashes, name)
+        )
+      }
+      self$repository_cas_lookup_table <- lookup_table
+    },
+    set_repository_hash_table = function(repository, data) {
+      self$repository_key_lookup[[repository]] <- list2env(
+        as.list(data),
+        parent = tar_envir_empty,
+        hash = TRUE
+      )
+    },
     migrate_database = function() {
       # Add the repository column (> 0.10.0).
       if (!file.exists(self$database$path)) {
@@ -150,7 +182,7 @@ meta_class <- R6::R6Class(
     },
     validate = function() {
       self$database$validate()
-      memory_validate(self$depends)
+      lookup_validate(self$depends)
     }
   )
 )
