@@ -1,8 +1,15 @@
 #' @export
 store_class_format.file <- function(format) {
-  c("tar_store_file", "tar_external", "tar_store")
+  store_class_format_file
 }
 
+#' @export
+store_class_format.file_fast <- function(format) {
+  store_class_format_file
+}
+
+store_class_format_file <- c("tar_store_file", "tar_external", "tar_store")
+
 #' @export
 store_assert_format_setting.file <- function(format) {
 }
@@ -17,7 +24,7 @@ store_read_path.tar_store_file <- function(store, path) {
 }
 
 #' @export
-store_write_object.tar_store_file <- function(store, object) {
+store_write_object.tar_store_file <- function(store, file, object) {
 }
 
 #' @export
@@ -51,17 +58,23 @@ store_assert_format.tar_store_file <- function(store, object, name) { # nolint
 }
 
 #' @export
-store_update_stage_early.tar_store_file <- function(store, name, path_store) {
+store_update_stage_early.tar_store_file <- function(
+  store,
+  file,
+  name,
+  path_store
+) {
 }
 
 #' @export
 store_update_stage_late.tar_store_file <- function(
   store,
+  file,
   name,
   object,
   path_store
 ) {
-  store$file$stage <- store_produce_stage(
+  file$stage <- store_produce_stage(
     store = store,
     name = name,
     object = object,
@@ -70,24 +83,25 @@ store_update_stage_late.tar_store_file <- function(
 }
 
 #' @export
-store_hash_early.tar_store_file <- function(store) { # nolint
-  tar_assert_path(store$file$path)
-  file_update_hash(store$file)
+store_hash_early.tar_store_file <- function(store, file) { # nolint
+  tar_assert_path(file$path)
+  file_update_hash(file)
 }
 
 #' @export
-store_hash_late.tar_store_file <- function(store) { # nolint
+store_hash_late.tar_store_file <- function(store, file) { # nolint
 }
 
 #' @export
 store_ensure_correct_hash.tar_store_file <- function(
   store,
+  file,
   storage,
   deployment
 ) {
   if_any(
     identical(deployment, "worker"),
-    store_wait_correct_hash(store),
-    tar_assert_path(store$file$path)
+    store_wait_correct_hash(store, file),
+    tar_assert_path(file$path)
   )
 }
