@@ -15,14 +15,15 @@
 #' @importFrom base64url base64_urldecode base64_urlencode
 #' @importFrom callr r r_bg
 #' @importFrom cli col_blue col_green col_red col_yellow make_spinner
-#'   num_ansi_colors symbol
+#'   num_ansi_colors style_hyperlink symbol
 #' @importFrom codetools findGlobals
 #' @importFrom data.table data.table fread fwrite rbindlist set
 #' @importFrom igraph adjacent_vertices as_edgelist gorder
 #'   graph_from_data_frame igraph_opt igraph_options is_dag simplify topo_sort
 #'   V
 #' @importFrom knitr engine_output knit_engines
-#' @importFrom ps ps_create_time ps_handle
+#' @importFrom ps ps_create_time ps_disk_partitions ps_fs_mount_point
+#'   ps_handle
 #' @importFrom R6 R6Class
 #' @importFrom rlang abort as_function check_installed enquo inform
 #'   is_installed quo_squash warn
@@ -40,9 +41,10 @@ NULL
 
 utils::globalVariables(
   c(
-    "example_target",
     ".targets_gc_5048826d",
     ".targets_target_5048826d",
+    "cas",
+    "example_target",
     "self"
   )
 )
