@@ -2,7 +2,7 @@
 # And afterwards, manually verify that all the buckets are gone.
 tar_test("aws_qs format data gets stored", {
   skip_if_no_aws()
-  skip_if_not_installed("qs")
+  skip_if_not_installed("qs2")
   s3 <- paws.storage::s3()
   bucket_name <- random_bucket_name()
   on.exit(aws_s3_delete_bucket(bucket_name))
@@ -51,7 +51,7 @@ tar_test("aws_qs format data gets stored", {
 
 tar_test("aws_qs format data gets stored with worker storage", {
   skip_if_no_aws()
-  skip_if_not_installed("qs")
+  skip_if_not_installed("qs2")
   s3 <- paws.storage::s3()
   bucket_name <- random_bucket_name()
   s3$create_bucket(Bucket = bucket_name)
@@ -102,7 +102,7 @@ tar_test("aws_qs format data gets stored with worker storage", {
 
 tar_test("aws_qs format invalidation", {
   skip_if_no_aws()
-  skip_if_not_installed("qs")
+  skip_if_not_installed("qs2")
   s3 <- paws.storage::s3()
   bucket_name <- random_bucket_name()
   s3$create_bucket(Bucket = bucket_name)
@@ -121,8 +121,8 @@ tar_test("aws_qs format invalidation", {
   expr <- tar_tidy_eval(expr, environment(), TRUE)
   eval(as.call(list(`tar_script`, expr, ask = FALSE)))
   tar_make(callr_function = NULL)
-  expect_equal(tar_progress(x)$progress, "built")
-  expect_equal(tar_progress(y)$progress, "built")
+  expect_equal(tar_progress(x)$progress, "completed")
+  expect_equal(tar_progress(y)$progress, "completed")
   tar_make(callr_function = NULL)
   progress <- tar_progress()
   progress <- progress[progress$progress != "skipped", ]
@@ -141,15 +141,15 @@ tar_test("aws_qs format invalidation", {
   expr <- tar_tidy_eval(expr, environment(), TRUE)
   eval(as.call(list(`tar_script`, expr, ask = FALSE)))
   tar_make(callr_function = NULL)
-  expect_equal(tar_progress(x)$progress, "built")
-  expect_equal(tar_progress(y)$progress, "built")
+  expect_equal(tar_progress(x)$progress, "completed")
+  expect_equal(tar_progress(y)$progress, "completed")
   expect_equal(tar_read(x), "x_value2")
   expect_equal(tar_read(y), c("x_value2", "y_value"))
 })
 
 tar_test("aws_qs format and dynamic branching", {
   skip_if_no_aws()
-  skip_if_not_installed("qs")
+  skip_if_not_installed("qs2")
   s3 <- paws.storage::s3()
   bucket_name <- random_bucket_name()
   s3$create_bucket(Bucket = bucket_name)
@@ -181,7 +181,7 @@ tar_test("aws_qs format and dynamic branching", {
 
 tar_test("aws timestamp", {
   skip_if_no_aws()
-  skip_if_not_installed("qs")
+  skip_if_not_installed("qs2")
   s3 <- paws.storage::s3()
   bucket_name <- random_bucket_name()
   s3$create_bucket(Bucket = bucket_name)
@@ -211,7 +211,7 @@ tar_test("aws timestamp", {
 
 tar_test("aws_qs format with an alternative data store", {
   skip_if_no_aws()
-  skip_if_not_installed("qs")
+  skip_if_not_installed("qs2")
   tar_config_set(store = "custom_targets_store")
   s3 <- paws.storage::s3()
   bucket_name <- random_bucket_name()
@@ -261,7 +261,7 @@ tar_test("aws_qs format with an alternative data store", {
 
 tar_test("aws_qs format works with storage = \"none\"", {
   skip_if_no_aws()
-  skip_if_not_installed("qs")
+  skip_if_not_installed("qs2")
   s3 <- paws.storage::s3()
   bucket_name <- random_bucket_name()
   s3$create_bucket(Bucket = bucket_name)
@@ -316,7 +316,7 @@ tar_test("aws_qs format works with storage = \"none\"", {
 
 tar_test("aws_qs format with custom region", {
   skip_if_no_aws()
-  skip_if_not_installed("qs")
+  skip_if_not_installed("qs2")
   s3 <- paws.storage::s3()
   bucket_name <- random_bucket_name()
   region <- region <- ifelse(
@@ -393,7 +393,7 @@ tar_test("aws_qs format with custom region", {
 
 tar_test("aws_qs format empty region string", {
   skip_if_no_aws()
-  skip_if_not_installed("qs")
+  skip_if_not_installed("qs2")
   s3 <- paws.storage::s3()
   bucket_name <- random_bucket_name()
   s3$create_bucket(Bucket = bucket_name)
@@ -421,7 +421,7 @@ tar_test("aws_qs format empty region string", {
 
 tar_test("aws_qs nonexistent bucket", {
   skip_if_no_aws()
-  skip_if_not_installed("qs")
+  skip_if_not_installed("qs2")
   s3 <- paws.storage::s3()
   bucket_name <- random_bucket_name()
   s3$create_bucket(Bucket = bucket_name)
@@ -457,7 +457,7 @@ tar_test("aws_qs nonexistent bucket", {
 tar_test("aws_qs format versioning", {
   # setup
   skip_if_no_aws()
-  skip_if_not_installed("qs")
+  skip_if_not_installed("qs2")
   s3 <- paws.storage::s3()
   bucket_name <- random_bucket_name()
   on.exit(aws_s3_delete_bucket(bucket_name))
@@ -473,7 +473,10 @@ tar_test("aws_qs format versioning", {
   expr <- quote({
     tar_option_set(
       resources = tar_resources(
-        aws = tar_resources_aws(bucket = !!bucket_name, prefix = "_targets")
+        aws = tar_resources_aws(
+          bucket = !!bucket_name,
+          prefix = "_targets"
+        )
       )
     )
     list(
@@ -484,7 +487,7 @@ tar_test("aws_qs format versioning", {
   eval(as.call(list(`tar_script`, expr, ask = FALSE)))
   expect_equal(targets::tar_outdated(callr_function = NULL), "x")
   tar_make(callr_function = NULL)
-  expect_equal(tar_progress(x)$progress, "built")
+  expect_equal(tar_progress(x)$progress, "completed")
   first_meta <- tempfile()
   file.copy(path_meta(path_store_default()), first_meta)
   expect_equal(targets::tar_outdated(callr_function = NULL), character(0))
@@ -495,7 +498,10 @@ tar_test("aws_qs format versioning", {
   expr <- quote({
     tar_option_set(
       resources = tar_resources(
-        aws = tar_resources_aws(bucket = !!bucket_name, prefix = "_targets")
+        aws = tar_resources_aws(
+          bucket = !!bucket_name,
+          prefix = "_targets"
+        )
       )
     )
     list(
@@ -506,7 +512,7 @@ tar_test("aws_qs format versioning", {
   eval(as.call(list(`tar_script`, expr, ask = FALSE)))
   expect_equal(targets::tar_outdated(callr_function = NULL), "x")
   tar_make(callr_function = NULL)
-  expect_equal(tar_progress(x)$progress, "built")
+  expect_equal(tar_progress(x)$progress, "completed")
   expect_equal(targets::tar_outdated(callr_function = NULL), character(0))
   tar_make(callr_function = NULL)
   expect_equal(tar_progress(x)$progress, "skipped")
@@ -519,7 +525,10 @@ tar_test("aws_qs format versioning", {
   expr <- quote({
     tar_option_set(
       resources = tar_resources(
-        aws = tar_resources_aws(bucket = !!bucket_name, prefix = "_targets")
+        aws = tar_resources_aws(
+          bucket = !!bucket_name,
+          prefix = "_targets"
+        )
       )
     )
     list(
@@ -528,14 +537,14 @@ tar_test("aws_qs format versioning", {
   })
   expr <- tar_tidy_eval(expr, environment(), TRUE)
   eval(as.call(list(`tar_script`, expr, ask = FALSE)))
-  expect_equal(targets::tar_outdated(callr_function = NULL), character(0))
+  expect_equal(targets::tar_outdated(callr_function = NULL), "x")
   tar_make(callr_function = NULL)
-  expect_equal(tar_progress(x)$progress, "skipped")
+  expect_equal(tar_progress(x)$progress, "completed")
 })
 
 tar_test("cloud target paths are not in the file path cache", {
   skip_if_no_aws()
-  skip_if_not_installed("qs")
+  skip_if_not_installed("qs2")
   s3 <- paws.storage::s3()
   bucket_name <- random_bucket_name()
   on.exit(aws_s3_delete_bucket(bucket_name))
