@@ -20,9 +20,11 @@ tar_test("does not inherit from tar_external", {
 
 tar_test("store_row_path()", {
   skip_cran()
-  store <- tar_target(x, "x_value", format = "keras")$store
-  store$file$path <- "path"
-  expect_equal(store_row_path(store), NA_character_)
+  target <- tar_target(x, "x_value", format = "keras")
+  store <- target$store
+  file <- target$file
+  file$path <- "path"
+  expect_equal(store_row_path(store, file), NA_character_)
 })
 
 tar_test("store_path_from_record()", {
