@@ -6,7 +6,7 @@ tar_test("tar_exist_process()", {
 })
 
 tar_test("custom script and store args", {
-  skip_on_cran()
+  skip_cran()
   expect_equal(tar_config_get("script"), path_script_default())
   expect_equal(tar_config_get("store"), path_store_default())
   tar_script(tar_target(x, 1), script = "example/script.R")
